@@ -30,7 +30,10 @@ class Visualization:
     def visual(self):
         x_center_point, y_center_point, x_point, y_point = self.format_point()
         fig, ax = plt.subplots()
-        colors = ['r', 'g', 'b', 'y', 'c', 'm']
+        colors = ['#FFB6C1', '#DC143C', '#FF00FF', '#800080', '#4B0082', '#6A5ACD',
+                  '#0000FF', '#6495ED', '#778899', '#1E90FF', '#B0E0E6', '#00FFFF',
+                  '#008B8B', '#48D1CC', '#00FA9A', '#2E8B57', '#FFFF00', '#BDB76B',
+                  '#DAA520', '#FFA500', '#FF8C00', '#000000', '#808080', '#8B0000', ]
         for i in range(len(x_point)):
             ax.scatter(x_point[i], y_point[i], c=colors[i])
         ax.scatter(x_center_point, y_center_point, marker='*', s=200, c='black')
